@@ -5,7 +5,7 @@
 
  */
  
-#include <xmlstring.h>
+#include <libxml/xmlstring.h>
 
 #include "procdefs.h"
 #include "agt.h"
