@@ -3,16 +3,18 @@
     namespace urn:ietf:params:xml:ns:yang:ietf-interfaces
  */
  
-#include <xmlstring.h>
+#include <libxml/xmlstring.h>
 #include <ctype.h>
 #include <string.h>
 #include <assert.h>
 #include "procdefs.h"
 #include "agt.h"
 #include "agt_cb.h"
+#include "agt_cli.h"
 #include "agt_timer.h"
 #include "agt_util.h"
 #include "agt_not.h"
+#include "agt_nmda.h"
 #include "agt_rpc.h"
 #include "dlq.h"
 #include "ncx.h"
@@ -24,10 +26,9 @@
 #include "val123.h"
 
 /* module static variables */
-static ncx_module_t *ietf_interfaces_mod;
-static obj_template_t* interfaces_state_obj;
-
-static val_value_t* root_prev_val=NULL;
+static val_value_t* root_prev_val;
+static val_value_t* with_nmda_param_val;
+static     uint32 timer_id;
 
 static void my_send_link_state_notification(char* new_state, char* if_name)
 {
@@ -80,7 +81,6 @@ static void my_send_link_state_notification(char* new_state, char* if_name)
     agt_not_queue_notification(notif);
 }
 
-
 void oper_status_update(val_value_t* cur_val)
 {
     status_t res;
@@ -124,7 +124,7 @@ void oper_status_update(val_value_t* cur_val)
         /* notify */
         name_val=val_find_child(cur_val->parent,"ietf-interfaces","name");
         assert(name_val);
-        printf("Notification /interfaces-state/interface[name=%s]: oper-status changes from %s to %s at %s\n", VAL_STRING(name_val), VAL_STRING(prev_val),VAL_STRING(cur_val), VAL_STRING(last_change_val));
+        printf("Notification /interfaces/interface[name=%s]: oper-status changes from %s to %s at %s\n", VAL_STRING(name_val), VAL_STRING(prev_val),VAL_STRING(cur_val), VAL_STRING(last_change_val));
         my_send_link_state_notification(VAL_STRING(cur_val), VAL_STRING(name_val));
 
     }
@@ -220,7 +220,7 @@ Inter-|   Receive                                                |  Transmit
  */
  
 static status_t
-    add_interfaces_state_entry(char* buf, val_value_t* interfaces_state_val)
+    add_interface_entry(char* buf, val_value_t* interfaces_val)
 {
     /*objs*/
     obj_template_t* interface_obj;
@@ -291,8 +291,8 @@ static status_t
     	str++;
     }
 
-    /* /interfaces-state/interface */
-    interface_obj = obj_find_child(interfaces_state_val->obj,
+    /* interface */
+    interface_obj = obj_find_child(interfaces_val->obj,
                                    "ietf-interfaces",
                                    "interface");
     assert(interface_obj != NULL);
@@ -304,9 +304,9 @@ static status_t
 
     val_init_from_template(interface_val, interface_obj);
 
-    val_add_child(interface_val, interfaces_state_val);
+    val_add_child(interface_val, interfaces_val);
 
-    /* /interfaces-state/interface/name */
+    /* interface/name */
     name_obj = obj_find_child(interface_obj,
                               "ietf-interfaces",
                               "name");
@@ -327,7 +327,7 @@ static status_t
     res = val_gen_index_chain(interface_obj, interface_val);
     assert(res == NO_ERR);
 
-    /* /interfaces-state/interface/oper-state */
+    /* interface/oper-state */
     oper_status_obj = obj_find_child(interface_obj,
                          "ietf-interfaces",
                          "oper-status");
@@ -341,7 +341,7 @@ static status_t
 
     val_add_child(oper_status_val, interface_val);
 
-    /* /interfaces-state/interface/oper-state */
+    /* interface/oper-state */
     last_change_obj = obj_find_child(interface_obj,
                          "ietf-interfaces",
                          "last-change");
@@ -355,7 +355,7 @@ static status_t
 
     val_add_child(last_change_val, interface_val);
 
-    /* /interfaces-state/interface/statistics */
+    /* interface/statistics */
     statistics_obj = obj_find_child(interface_obj,
                          "ietf-interfaces",
                          "statistics");
@@ -402,10 +402,10 @@ static status_t
     return res;
 }
 
-/* Registered callback functions: get_interfaces_state */
+/* Registered callback functions: get_interfaces */
 
 static status_t
-    get_interfaces_state(ses_cb_t *scb,
+    get_interfaces(ses_cb_t *scb,
                          getcb_mode_t cbmode,
                          val_value_t *vir_val,
                          val_value_t *dst_val)
@@ -447,7 +447,7 @@ static status_t
             continue;
         }
 
-        res = add_interfaces_state_entry(buf, dst_val);
+        res = add_interface_entry(buf, dst_val);
         if (res != NO_ERR) {
              done = TRUE;
         }
@@ -459,42 +459,32 @@ static status_t
     return res;
 }
 
-int
-    my_timer_fn (uint32 timer_id,
-                      void *cookie)
+int my_timer_fn(uint32 timer_id, void *cookie)
 {
     /*
      * Brute force method for polling for connection state changes
      * without this link-up and link-down notifications will be
      * generated only when someone reads oper-state
      */
-    cfg_template_t* runningcfg;
-    val_value_t* interfaces_state_val;
+    val_value_t* root_system_val;
+    val_value_t* interfaces_val = cookie;
     xmlChar* dummy_serialized_data_str;
     status_t res;
 
-    runningcfg = cfg_get_config_id(NCX_CFGID_RUNNING);
-    assert(runningcfg && runningcfg->root);
+    res = NO_ERR;
 
-    interfaces_state_val = val_find_child(runningcfg->root,
-                                          "ietf-interfaces",
-                                          "interfaces-state");
-    assert(interfaces_state_val);
-    res = val_make_serialized_string (interfaces_state_val, NCX_DISPLAY_MODE_JSON, &dummy_serialized_data_str);
+    /* by serializing the value all virtual node callbacks are periodically executed */
+    res = val_make_serialized_string(interfaces_val, NCX_DISPLAY_MODE_JSON, &dummy_serialized_data_str);
     free(dummy_serialized_data_str);
 
-#if 0 /*for simulation*/
-    {
-        static unsigned int counter=0;
-        my_send_link_state_notification((counter%2)?"up":"down", "eth0");
-        my_send_link_state_notification((counter%2)?"up":"down", "eth1");
-        counter++;
-    }
-#endif
     return 0;
 
 }
 
+static status_t init2_w_nmda(void)
+{
+}
+
 /* The 3 mandatory callback functions: y_ietf_interfaces_init, y_ietf_interfaces_init2, y_ietf_interfaces_cleanup */
 
 status_t
@@ -503,77 +493,121 @@ status_t
         const xmlChar *revision)
 {
     agt_profile_t *agt_profile;
+    ncx_module_t *mod;
     status_t res;
 
+    val_value_t *clivalset;
+
+    /* check for --with-nmda=true (param defined in netconfd-ex.yang) */
+    clivalset = agt_cli_get_valset();
+    with_nmda_param_val = val_find_child(clivalset, "netconfd-ex", "with-nmda");
+
     agt_profile = agt_get_profile();
 
     res = ncxmod_load_module(
         "ietf-interfaces",
         NULL,
         &agt_profile->agt_savedevQ,
-        &ietf_interfaces_mod);
-    if (res != NO_ERR) {
-        return res;
+        &mod);
+    assert(res == NO_ERR);
+
+    if(with_nmda_param_val && VAL_BOOL(with_nmda_param_val)) {
+        assert(0==strcmp(mod->version,"2018-02-20"));
+    } else {
+        assert(0==strcmp(mod->version,"2014-05-08"));
     }
 
-    interfaces_state_obj = ncx_find_object(
-        ietf_interfaces_mod,
-        "interfaces-state");
-    if (interfaces_state_obj == NULL) {
-        return SET_ERROR(ERR_NCX_DEF_NOT_FOUND);
-    }
-    
+    res = ncxmod_load_module(
+        "iana-if-type",
+        NULL,
+        &agt_profile->agt_savedevQ,
+        &mod);
+    assert(res == NO_ERR);
+
+    res = ncxmod_load_module(
+        "interfaces-notifications",
+        NULL,
+        &agt_profile->agt_savedevQ,
+        &mod);
+    assert(res == NO_ERR);
+
     return res;
 }
 
 status_t y_ietf_interfaces_init2(void)
 {
     status_t res;
-    cfg_template_t* runningcfg;
-    val_value_t* interfaces_state_val;
-    uint32 timer_id;
+    ncx_module_t* mod;
+    obj_template_t* interfaces_obj;
+    val_value_t* interfaces_val;
+    val_value_t* root_val;
 
     res = NO_ERR;
 
-    runningcfg = cfg_get_config_id(NCX_CFGID_RUNNING);
-    if (!runningcfg || !runningcfg->root) {
-        return SET_ERROR(ERR_INTERNAL_VAL);
+    mod = ncx_find_module("ietf-interfaces", NULL);
+    assert(mod);
+
+    if(with_nmda_param_val && VAL_BOOL(with_nmda_param_val)) {
+        root_val = agt_nmda_get_root_system();
+        assert(root_val);
+
+        interfaces_obj = ncx_find_object(
+            mod,
+            "interfaces");
+        assert(interfaces_obj);
+
+        interfaces_val = val_find_child(root_val,
+                                        "ietf-interfaces",
+                                        "interfaces");
+    } else {
+        cfg_template_t* runningcfg;
+
+        runningcfg = cfg_get_config_id(NCX_CFGID_RUNNING);
+        assert(runningcfg && runningcfg->root);
+        root_val = runningcfg->root;
+        interfaces_obj = ncx_find_object(
+            mod,
+            "interfaces-state");
+        assert(interfaces_obj);
+        interfaces_val = val_find_child(root_val,
+                                        "ietf-interfaces",
+                                        "interfaces-state");
+        
     }
 
-    interfaces_state_val = val_find_child(runningcfg->root,
-                                          "ietf-interfaces",
-                                          "interfaces-state");
-    /* Can not coexist with other implementation
-     * of ietf-interfaces.
-     */
-    if(interfaces_state_val!=NULL) {
-        log_error("\nError: /interfaces-state already present!");
-        return SET_ERROR(ERR_INTERNAL_VAL);
-    }
+    /* not designed to coexist with other implementations */
+    assert(interfaces_val==NULL);
 
-    interfaces_state_val = val_new_value();
-    if (interfaces_state_val == NULL) {
-        return SET_ERROR(ERR_INTERNAL_VAL);
-    }
+    interfaces_val = val_new_value();
+    assert(interfaces_val);
 
-    val_init_virtual(interfaces_state_val,
-                     get_interfaces_state,
-                     interfaces_state_obj);
+    val_init_virtual(interfaces_val,
+                     get_interfaces,
+                     interfaces_obj);
 
-    val_add_child(interfaces_state_val, runningcfg->root);
+    val_add_child(interfaces_val, root_val);
 
     /* init a root value to store copies of prev state data values */
     root_prev_val = val_new_value();
-    val_init_from_template(root_prev_val, runningcfg->root->obj);
+    val_init_from_template(root_prev_val, root_val->obj);
 
     res = agt_timer_create(1/* 1 sec period */,
                            TRUE/*periodic*/,
                            my_timer_fn,
-                           NULL/*cookie*/,
+                           interfaces_val/*cookie*/,
                            &timer_id);
     return res;
 }
 
+
 void y_ietf_interfaces_cleanup (void)
 {
+#if 0
+    agt_cb_unregister_callbacks( "ietf-interfaces",
+                               (const xmlChar *)"/interfaces/interface");
+    agt_cb_unregister_callbacks( "ietf-interfaces",
+                               (const xmlChar *)"/interfaces/interface/enable");
+#endif
+    agt_timer_delete(timer_id);
 }
+
