@@ -370,7 +370,7 @@ status_t
         /* Service all the sockets with input and/or output pending */
         done2 = FALSE;
         for (i = 0; i < max(maxrdnum+1, maxwrnum+1) && !done2; i++) {
-
+            scb=NULL;
             /* check write output to client sessions */
             if (!stream_output && FD_ISSET(i, &write_fd_set)) {
                 /* try to send 1 packet worth of buffers for a session */
@@ -449,6 +449,8 @@ status_t
                      * Need to have the xmlreader for this session
                      */
                     scb = def_reg_find_scb(i);
+
+ses_accept_defered_input:
                     if (scb != NULL) {
                         res = ses_accept_input(scb);
                         if (res != NO_ERR) {
@@ -495,6 +497,15 @@ status_t
                     send_some_notifications();
                 }
             }
+            if(scb && scb->indefer_len>0) {
+                /*
+                 * input defered until previous message
+                 * is processed e.g. <rpc> trailing <hello>
+                 */
+                log_debug3("\nagt_ncxserver: goto deferred trailing input processing.");
+
+                goto ses_accept_defered_input;
+            }
         }
     }  /* end select loop */
 
