@@ -50,6 +50,7 @@ date         init     comment
 #include  "dlq.h"
 #include  "log.h"
 #include  "ncx.h"
+#include  "ncxmod.h"
 #include  "ncx_feature.h"
 #include  "ncx_list.h"
 #include  "ncxconst.h"
@@ -1121,10 +1122,12 @@ status_t
         parmname = xmlns_get_module(foundnsid);
         if (cap->cap_module != NULL && xml_strcmp(parmname, cap->cap_module)) {
             if (usewarning) {
-                log_warn("\nWarning: capability base URI mismatch, "
-                         "got '%s' not '%s''", 
-                         cap->cap_module,  
-                         parmname);
+                if(!(0==strcmp(cap->cap_module, NCXMOD_IETF_NETCONF) && 0==strcmp(parmname,NCXMOD_NETCONF))) {
+                    log_warn("\nWarning: capability base URI mismatch, "
+                             "got '%s' not '%s''",
+                             cap->cap_module,
+                             parmname);
+                }
             }
         }
     }
@@ -1638,6 +1641,20 @@ status_t
         return ERR_INTERNAL_MEM;
     }
 
+    if(0==strcmp(mod->name, NCXMOD_NETCONF)) {
+        /* ietf-netconf is overloaded internally */
+        char* newstr;
+        char* features_str;
+        char* pre_features_str = "urn:ietf:params:xml:ns:netconf:base:1.0?module=ietf-netconf&revision=2011-06-01&";
+        features_str = strstr(str, "features=");
+        assert(features_str);
+        newstr = malloc(strlen(pre_features_str)+strlen(features_str)+1);
+        assert(newstr);
+        sprintf(newstr,"%s%s",pre_features_str, features_str);
+        free(str);
+        str = newstr;
+    }
+
     /* make the capability element */
     capval = xml_val_new_string(NCX_EL_CAPABILITY,
                                 xmlns_nc_id(), 
