@@ -79,7 +79,7 @@ date             init     comment
 29-may-08    abb      Converted NCX database model to simplified
                       YANG object model
 */
-#include <xmlstring.h>
+#include <libxml/xmlstring.h>
 
 #ifndef _H_dlq
 #include "dlq.h"
