@@ -40,7 +40,7 @@ date         init     comment
 #include <memory.h>
 #include <string.h>
 #include <ctype.h>
-#include <xmlstring.h>
+#include <libxml/xmlstring.h>
 #include <assert.h>
 
 #include  "procdefs.h"
@@ -243,9 +243,9 @@ static status_t
         } else {
             /* get the base type value */
             btyp = obj_get_basetype(obj);
-            if (btyp == NCX_BT_ANY || typ_is_simple(btyp)) {
+            if (btyp == NCX_BT_ANYDATA || btyp == NCX_BT_ANYXML || typ_is_simple(btyp)) {
                 typdef = obj_get_typdef(obj);
-                if (btyp != NCX_BT_ANY) {
+                if (btyp != NCX_BT_ANYDATA && btyp != NCX_BT_ANYXML) {
                     res = val_simval_ok(typdef, strval);
                 }
                 if (res == NO_ERR) {
@@ -1612,6 +1612,10 @@ val_value_t *
             if (parmname != NULL) {
                 xml_strncpy(errbuff, (const xmlChar *)parmname, 
                             min(parmnamelen, ERRLEN));
+            } else if(isdefaultparm) {
+                xml_strncpy(errbuff, (const xmlChar *)"(in default parm)",
+                            min(strlen("(in default parm)"), ERRLEN));
+
             } else {
                 xml_strncpy(errbuff, (const xmlChar *)&buff[buffpos],
                             min(strlen(&buff[buffpos]), ERRLEN));
