@@ -61,7 +61,7 @@ date	     init     comment
 23-aug-09    abb      Update diagram in header
 */
 
-#include <xmlstring.h>
+#include <libxml/xmlstring.h>
 
 #ifndef _H_dlq
 #include "dlq.h"
@@ -1136,7 +1136,7 @@ extern ncx_identity_t *
 *    pointer to found identity or NULL if not found
 *********************************************************************/
 extern ncx_identity_t *
-    ncx_find_identity_que (dlq_hdr_t *identityQ,
+    ncx_find_identity_que (const dlq_hdr_t *identityQ,
 			   const xmlChar *name);
 
 
