@@ -34,7 +34,7 @@ date	     init     comment
 */
 
 #include <math.h>
-#include <xmlstring.h>
+#include <libxml/xmlstring.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -398,6 +398,7 @@ extern "C" {
 #define NCX_EL_ADDRESS         (const xmlChar *)"address"
 #define NCX_EL_ALT_NAME        (const xmlChar *)"alt-name"
 #define NCX_EL_ANY             (const xmlChar *)"any"
+#define NCX_EL_ANYDATA          (const xmlChar *)"anydata"
 #define NCX_EL_ANYXML          (const xmlChar *)"anyxml"
 #define NCX_EL_APPINFO         (const xmlChar *)"appinfo"
 #define NCX_EL_APPLICATION     (const xmlChar *)"application"
@@ -667,6 +668,7 @@ extern "C" {
 #define NCX_EL_TEXT            (const xmlChar *)"text"
 #define NCX_EL_TG2             (const xmlChar *)"tg2"
 #define NCX_EL_TIMEOUT         (const xmlChar *)"timeout"
+#define NCX_EL_TREE            (const xmlChar *)"tree"
 #define NCX_EL_TXT             (const xmlChar *)"txt"
 #define NCX_EL_TRANSPORT       (const xmlChar *)"transport"
 #define NCX_EL_TRIM            (const xmlChar *)"trim"
@@ -710,6 +712,7 @@ extern "C" {
 #define NCX_EL_WHEN            (const xmlChar *)"when"
 #define NCX_EL_WITH_DEFAULTS   (const xmlChar *)"with-defaults"
 #define NCX_EL_WITH_METADATA   (const xmlChar *)"with-metadata"
+#define NCX_EL_WITH_NMDA       (const xmlChar *)"with-nmda"
 #define NCX_EL_WITH_STARTUP    (const xmlChar *)"with-startup"
 #define NCX_EL_WITH_URL        (const xmlChar *)"with-url"
 #define NCX_EL_WITH_VALIDATE   (const xmlChar *)"with-validate"
@@ -761,7 +764,7 @@ extern "C" {
 
 
 #define COPYRIGHT_STRING_LINE0 "Copyright (c) 2008-2012, Andy Bierman, All Rights Reserved.\n"
-#define COPYRIGHT_STRING_LINE1 "Copyright (c) 2013-2017, Vladimir Vassilev, All Rights Reserved.\n"
+#define COPYRIGHT_STRING_LINE1 "Copyright (c) 2013-2018, Vladimir Vassilev, All Rights Reserved.\n"
 
 #define COPYRIGHT_STRING COPYRIGHT_STRING_LINE0 COPYRIGHT_STRING_LINE1
 
