@@ -42,7 +42,7 @@ date	     init     comment
 06-oct-09   abb       Change YANG_ env vars to YUMA_ 
 */
 
-#include <xmlstring.h>
+#include <libxml/xmlstring.h>
 
 #ifndef _H_cap
 #include "cap.h"
@@ -110,6 +110,7 @@ extern "C" {
 #define NCXMOD_YUMA_NETCONF   (const xmlChar *)"yuma123-netconf"
 
 #define NCXMOD_IETF_NETCONF   (const xmlChar *)"ietf-netconf"
+#define NCXMOD_IETF_NETCONF_REVISION   (const xmlChar *)"2011-06-01"
 
 #define NCXMOD_IETF_NETCONF_ACM  (const xmlChar *)"ietf-netconf-acm"
 
@@ -147,21 +148,11 @@ extern "C" {
  */
 #define NCXMOD_INSTALL   "YUMA_INSTALL"
 
-/* !! should import this from make !! */
-#ifdef FREEBSD
-#define NCXMOD_DEFAULT_INSTALL (const xmlChar *)"/usr/local/share/yuma"
-#else
-#define NCXMOD_DEFAULT_INSTALL (const xmlChar *)"/usr/share/yuma"
-#endif
+#define NCXMOD_DEFAULT_INSTALL (const xmlChar *)YUMA_DATAROOTDIR
 
-/* !! should import this from make !! */
-#define NCXMOD_DEFAULT_YUMALIB64 (const xmlChar *)"/usr/lib64/yuma"
+#define NCXMOD_DEFAULT_YUMALIB (const xmlChar *)NETCONFMODULEDIR
 
-#define NCXMOD_DEFAULT_YUMALIB (const xmlChar *)"/usr/lib/yuma"
-
-
-/* !! should import this from make !! */
-#define NCXMOD_ETC_DATA (const xmlChar *)"/etc/yuma"
+#define NCXMOD_ETC_DATA (const xmlChar *)SYSCONFDIR"/yuma"
 
 
 /* NCX Environment Variable for MODULE search path */
@@ -239,6 +230,7 @@ typedef struct ncxmod_search_result_t_ {
     uint32         nslen;         /* length of base part of namespacestr */
     cap_rec_t     *cap;           /* back-ptr to source capability URI */
     val_value_t   *module_val;    /* back-ptr to yang-library /module-state/module */
+    val_value_t   *submodule_val; /* back-ptr to yang-library /module-state/module/submodule */
     boolean        capmatch;      /* set by yangcli; internal use only */
     boolean        ismod;         /* TRUE=module; FALSE=submodule */
 } ncxmod_search_result_t;
@@ -1339,6 +1331,31 @@ extern boolean
 extern uint32
     ncxmod_get_pathlen_from_filespec (const xmlChar *filespec);
 
+/********************************************************************
+* FUNCTION ncxmod123_find_module_filespec
+*
+* Determine the location of the specified module
+*
+* Module Search order:
+*   1) current directory
+*   2) YUMA_MODPATH environment var (or set by modpath CLI var)
+*   3) HOME/modules directory
+*   4) YUMA_HOME/modules directory
+*   5) YUMA_INSTALL/modules directory OR
+*   6) default install module location, which is '/usr/share/yuma/modules'
+*
+* INPUTS:
+*   modname == module name with no path prefix or file extension
+*   revision == optional revision date of 'modname' to find
+**
+* RETURNS:
+*   NULL if no match was found or pointer to allocated string
+*   containing the path
+*
+*********************************************************************/
+extern xmlChar*
+    ncxmod123_find_module_filespec(const xmlChar *modname, const xmlChar *revision);
+
 #ifdef __cplusplus
 }  /* end extern 'C' */
 #endif
