@@ -33,8 +33,8 @@ date	     init     comment
 10-nov-07    abb      Split out from ncxconst.h
 */
 
-#include <xmlstring.h>
-#include <xmlregexp.h>
+#include <libxml/xmlstring.h>
+#include <libxml/xmlregexp.h>
 
 #ifndef _H_dlq
 #include "dlq.h"
@@ -141,7 +141,8 @@ typedef enum ncx_data_class_t_ {
  */
 typedef enum ncx_btype_t_ {
     NCX_BT_NONE,
-    NCX_BT_ANY,
+    NCX_BT_ANYDATA,
+    NCX_BT_ANYXML,
     NCX_BT_BITS,
     NCX_BT_ENUM,
     NCX_BT_EMPTY,
@@ -174,7 +175,7 @@ typedef enum ncx_btype_t_ {
 } ncx_btype_t;
 
 
-#define NCX_FIRST_DATATYPE NCX_BT_ANY
+#define NCX_FIRST_DATATYPE NCX_BT_ANYDATA
 #define NCX_LAST_DATATYPE  NCX_BT_LIST
 #define NCX_NUM_BASETYPES  (NCX_LAST_DATATYPE-NCX_FIRST_DATATYPE+1)
 
@@ -586,48 +587,6 @@ typedef struct ncx_filptr_t_ {
     dlq_hdr_t             childQ;  /* Q of ncx_filptr_t */
 } ncx_filptr_t;
 
-/* back pointer to a YANG identity
- * used to create an inline tree of valid values
- * for an identity used as a base
- *
- * This inline Q record will be linked in to the
- * childQ of the base identity when the identity
- * containing this struct is using it as a base
- *
- * This thread is only used for client help,
- * to easily list all the QName values that are permitted
- * for a identityref leaf
- */
-typedef struct ncx_idlink_t_ {
-    dlq_hdr_t  qhdr;
-    struct ncx_identity_t_ *identity;
-    boolean    inq;
-} ncx_idlink_t;
-
-/* YANG identity entry */
-typedef struct ncx_identity_t_ {
-    dlq_hdr_t             qhdr;
-    dlq_hdr_t             baseQ;
-    xmlChar              *name;
-    xmlChar              *descr;
-    xmlChar              *ref;
-    ncx_status_t          status;
-    dlq_hdr_t             appinfoQ;       /* Q of ncx_appinfo_t */
-    status_t              res;     /* may be stored with errors */
-    boolean               isroot;    /* empty baseQ not an error */
-    dlq_hdr_t             childQ;          /* Q of ncx_idlink_t */
-    ncx_error_t           tkerr;
-    boolean               seen;                  /* for yangcli */
-} ncx_identity_t;
-
-typedef struct ncx_identity_base_t_ {
-    dlq_hdr_t             qhdr;
-    xmlChar              *prefix;
-    xmlChar              *name;
-    ncx_identity_t       *identity;
-    ncx_idlink_t          idlink;
-} ncx_identity_base_t;
-
 /* representation of one module or submodule during and after parsing */
 typedef struct ncx_module_t_ {
     dlq_hdr_t         qhdr;
@@ -687,6 +646,49 @@ typedef struct ncx_module_t_ {
 
 } ncx_module_t;
 
+/* back pointer to a YANG identity
+ * used to create an inline tree of valid values
+ * for an identity used as a base
+ *
+ * This inline Q record will be linked in to the
+ * childQ of the base identity when the identity
+ * containing this struct is using it as a base
+ *
+ * This thread is only used for client help,
+ * to easily list all the QName values that are permitted
+ * for a identityref leaf
+ */
+typedef struct ncx_idlink_t_ {
+    dlq_hdr_t  qhdr;
+    struct ncx_identity_t_ *identity;
+    boolean    inq;
+} ncx_idlink_t;
+
+/* YANG identity entry */
+typedef struct ncx_identity_t_ {
+    dlq_hdr_t             qhdr;
+    dlq_hdr_t             baseQ;
+    ncx_module_t         *mod;
+    xmlChar              *name;
+    xmlChar              *descr;
+    xmlChar              *ref;
+    ncx_status_t          status;
+    dlq_hdr_t             appinfoQ;       /* Q of ncx_appinfo_t */
+    status_t              res;     /* may be stored with errors */
+    boolean               isroot;    /* empty baseQ not an error */
+    dlq_hdr_t             childQ;          /* Q of ncx_idlink_t */
+    ncx_error_t           tkerr;
+    boolean               seen;                  /* for yangcli */
+} ncx_identity_t;
+
+typedef struct ncx_identity_base_t_ {
+    dlq_hdr_t             qhdr;
+    xmlChar              *prefix;
+    xmlChar              *name;
+    ncx_identity_t       *identity;
+    ncx_idlink_t          idlink;
+} ncx_identity_base_t;
+
 
 /* enumeration for different NCX module conversion output types */
 typedef enum ncx_cvttyp_t_ {
@@ -705,7 +707,8 @@ typedef enum ncx_cvttyp_t_ {
     NCX_CVTTYP_YH,
     NCX_CVTTYP_YC,
     NCX_CVTTYP_UH,
-    NCX_CVTTYP_UC
+    NCX_CVTTYP_UC,
+    NCX_CVTTYP_TREE
 } ncx_cvttyp_t;
 
 
@@ -725,6 +728,8 @@ typedef struct ncx_import_t_ {
     xmlChar            *module;
     xmlChar            *prefix;
     xmlChar            *revision;
+    xmlChar            *description;
+    xmlChar            *reference;
     ncx_module_t       *mod;                   /* back-ptr */
     boolean             used;
     boolean             usexsd;        /* FALSE if duplicate */
