@@ -79,8 +79,8 @@ date	     init     comment
 
 
 /* From /usr/include/libxml2/libxml/ */
-#include <xmlreader.h>
-#include <xmlstring.h>
+#include <libxml/xmlreader.h>
+#include <libxml/xmlstring.h>
 
 #ifndef _H_ncxconst
 #include "ncxconst.h"
