@@ -35,7 +35,7 @@ date	     init     comment
 
 #include <time.h>
 //#include <sys/time.h>
-#include <xmlstring.h>
+#include <libxml/xmlstring.h>
 #include "libtecla.h"
 #include "ncxconst.h"
 #include "ncxmod.h"
@@ -212,6 +212,7 @@ extern "C" {
 #define YANGCLI_TIMEOUT     (const xmlChar *)"timeout"
 #define YANGCLI_TIME_RPCS   (const xmlChar *)"time-rpcs"
 #define YANGCLI_TRANSPORT   (const xmlChar *)"transport"
+#define YANGCLI_USE_AGENT   (const xmlChar *)"use-agent"
 #define YANGCLI_USE_XMLHEADER (const xmlChar *)"use-xmlheader"
 #define YANGCLI_USER        (const xmlChar *)"user"
 #define YANGCLI_USERVARS_FILE  (const xmlChar *)"uservars-file"
@@ -806,6 +807,20 @@ extern status_t
 extern void
     free_server_cb (server_cb_t *server_cb);
 
+/********************************************************************
+* FUNCTION enable_server_cb_interactive_mode
+*
+*  Add/Initialize interactive context properties.
+*
+* INPUTS:
+*    server_cb == server_cb struct
+*
+* RETURNS:
+*   status
+*********************************************************************/
+extern status_t
+    enable_server_cb_interactive_mode (server_cb_t* server_cb);
+
 /********************************************************************
 * FUNCTION new_server_cb
 * 
@@ -818,7 +833,7 @@ extern void
 *   malloced server_cb struct or NULL of malloc failed
 *********************************************************************/
 extern server_cb_t *
-    new_server_cb (const xmlChar *name, boolean interactive);
+    new_server_cb (const xmlChar *name);
 
 /********************************************************************
  * FUNCTION init_config_vars
