@@ -388,17 +388,6 @@ status_t yangrpc_init(char* args)
         return ERR_NCX_DEF_NOT_FOUND;
     }
 
-    /* treat the connect-to-server parmset special
-     * it is saved for auto-start plus restart parameters
-     * Setup an empty parmset to hold the connect parameters
-     */
-    connect_valset = val_new_value();
-    if (connect_valset==NULL) {
-        return ERR_INTERNAL_MEM;
-    } else {
-        val_init_from_template(connect_valset, obj);
-    }
-
 #if 0
     /* set the CLI handler */
     mgr_io_set_stdin_handler(yangcli_stdin_handler);
@@ -559,12 +548,28 @@ status_t yangrpc_connect(char* server, uint16_t port, char* user, char* password
     uint32                modlen;
     int                   ret;
     yangcli_wordexp_t     p;
+    obj_template_t       *obj;
+
+    ncx_clear_temp_modQ();
+    ncx_clear_session_modQ();
+
+    /* new connect_valset */
+    if(connect_valset!=NULL) {
+        val_free_value(connect_valset);
+        connect_valset=NULL;
+    }
+    connect_valset = val_new_value();
+    assert(connect_valset);
+    obj = ncx_find_object(yangcli_mod, YANGCLI_CONNECT);
+    assert(obj!=NULL);
+    val_init_from_template(connect_valset, obj);
 
     dlq_createSQue(&savedevQ);
 
     /* create a default server control block */
-    server_cb = new_server_cb(YANGCLI_DEF_SERVER, FALSE);
+    server_cb = new_server_cb(YANGCLI_DEF_SERVER);
     if (server_cb==NULL) {
+        log_error("\n new_server_cb failed (%s)", get_error_string(res));
         return ERR_INTERNAL_PTR;
     }
     argv = mandatory_argv;
@@ -614,6 +619,7 @@ status_t yangrpc_connect(char* server, uint16_t port, char* user, char* password
         ret = yangcli_wordexp(extra_args, &p, 0);
         if(ret!=0) {
             perror(extra_args);
+            log_error("\n yangcli_wordexp failed (%s)", get_error_string(ERR_CMDLINE_OPT_UNKNOWN));
             return ERR_CMDLINE_OPT_UNKNOWN;
         }
         extra_argc = p.we_wordc;
@@ -630,6 +636,7 @@ status_t yangrpc_connect(char* server, uint16_t port, char* user, char* password
     /* Get any command line and conf file parameters */
     res = process_cli_input(server_cb, argc, argv);
     if (res != NO_ERR) {
+        log_error("\n process_cli_input failed (%s)", get_error_string(res));
         return res;
     }
 
@@ -642,6 +649,7 @@ status_t yangrpc_connect(char* server, uint16_t port, char* user, char* password
     if (TRUE/*autoload*/) {
         res = load_core_schema();
         if (res != NO_ERR) {
+            log_error("\n load_core_schema failed (%s)", get_error_string(res));
             return res;
         }
     }
@@ -697,18 +705,21 @@ status_t yangrpc_connect(char* server, uint16_t port, char* user, char* password
     /* discard any deviations loaded from the CLI or conf file */
     ncx_clean_save_deviationsQ(&savedevQ);
     if (res != NO_ERR) {
+        log_error("\n ncx_clean_save_deviationsQ failed (%s)", get_error_string(res));
         return res;
     }
 
     /* load the system (read-only) variables */
     res = init_system_vars(server_cb);
     if (res != NO_ERR) {
+        log_error("\n init_system_vars failed (%s)", get_error_string(res));
         return res;
     }
 
     /* load the system config variables */
     res = init_config_vars(server_cb);
     if (res != NO_ERR) {
+        log_error("\n init_config_vars failed (%s)", get_error_string(res));
         return res;
     }
 
@@ -723,6 +734,7 @@ status_t yangrpc_connect(char* server, uint16_t port, char* user, char* password
         res = ncxmod_find_all_modules(&modlibQ);
         log_set_debug_level(dbglevel);
         if (res != NO_ERR) {
+            log_error("\n ncxmod_find_all_modules failed (%s)", get_error_string(res));
             return res;
         }
     }
@@ -787,6 +799,7 @@ status_t yangrpc_connect(char* server, uint16_t port, char* user, char* password
         while(1) {
             res = ses_accept_input(scb);
             if(res!=NO_ERR) {
+                log_error("\n ses_accept failed (%s)", get_error_string(res));
                 return res;
             }
             if(mgr_ses_process_first_ready()) {
@@ -901,10 +914,22 @@ status_t yangrpc_parse_cli(yangrpc_cb_ptr_t yangrpc_cb_ptr, char* original_line,
     boolean                shut = FALSE;
     ncx_node_t             dtyp;
     char* line;
+    ses_cb_t* scb;
+    mgr_scb_t* mscb;
 
     server_cb_t* server_cb;
     server_cb = (server_cb_t*)yangrpc_cb_ptr;
 
+    scb = mgr_ses_get_scb(server_cb->mysid);
+    if (!scb) {
+        res = SET_ERROR(ERR_INTERNAL_PTR);
+        return res;
+    }
+    mscb = (mgr_scb_t *)scb->mgrcb;
+    ncx_set_temp_modQ(&mscb->temp_modQ);
+    ncx_set_session_modQ(&mscb->temp_modQ);
+
+
     line = strdup(original_line);
 #ifdef DEBUG
     if (!server_cb || !line) {
@@ -1057,6 +1082,7 @@ status_t yangrpc_exec(yangrpc_cb_ptr_t yangrpc_cb_ptr, val_value_t* request_val,
 {
     status_t res;
     ses_cb_t* scb;
+    mgr_scb_t* mscb;
     mgr_rpc_req_t         *req;
     server_cb_t* server_cb;
     server_cb = (server_cb_t*)yangrpc_cb_ptr;
@@ -1066,6 +1092,10 @@ status_t yangrpc_exec(yangrpc_cb_ptr_t yangrpc_cb_ptr, val_value_t* request_val,
         res = SET_ERROR(ERR_INTERNAL_PTR);
         return res;
     }
+    mscb = (mgr_scb_t *)scb->mgrcb;
+    ncx_set_temp_modQ(&mscb->temp_modQ);
+    ncx_set_session_modQ(&mscb->temp_modQ);
+
     req = mgr_rpc_new_request(scb);
     if (!req) {
         res = ERR_INTERNAL_MEM;
@@ -1101,4 +1131,5 @@ status_t yangrpc_exec(yangrpc_cb_ptr_t yangrpc_cb_ptr, val_value_t* request_val,
 
 void yangrpc_close(yangrpc_cb_ptr_t yangrpc_cb_ptr)
 {
+    log_info("Closing session\n");
 }
