@@ -52,8 +52,8 @@ date         init     comment
 #include <memory.h>
 #include <ctype.h>
 
-#include <xmlstring.h>
-#include <xmlreader.h>
+#include <libxml/xmlstring.h>
+#include <libxml/xmlreader.h>
 
 #include "procdefs.h"
 #include "c.h"
