@@ -8,7 +8,7 @@ fi
 rm -rf tmp || true
 mkdir tmp
 
-/usr/sbin/netconfd --validate-config-only --startup-error=stop --startup=startup-cfg-good.xml --module=/usr/share/yuma/modules/ietf/ietf-interfaces.yang --module=/usr/share/yuma/modules/ietf/iana-if-type.yang 1>tmp/netconfd.stdout 2>tmp/netconfd.stderr
+/usr/sbin/netconfd --validate-config-only --startup-error=stop --startup=startup-cfg-good.xml --module=/usr/share/yuma/modules/ietf/ietf-interfaces@2014-05-08.yang --module=/usr/share/yuma/modules/ietf/iana-if-type@2014-05-08.yang 1>tmp/netconfd.stdout 2>tmp/netconfd.stderr
 GOOD_RES=$?
 cat tmp/netconfd.stdout
 if [ "$GOOD_RES" != "0" ] ; then
@@ -18,7 +18,7 @@ else
     echo "OK: Validated with startup-cfg-good.xml"
 fi
 
-/usr/sbin/netconfd --validate-config-only --startup-error=stop --startup=startup-cfg-bad.xml --module=/usr/share/yuma/modules/ietf/ietf-interfaces.yang --module=/usr/share/yuma/modules/ietf/iana-if-type.yang 1>tmp/netconfd.stdout 2>tmp/netconfd.stderr
+/usr/sbin/netconfd --validate-config-only --startup-error=stop --startup=startup-cfg-bad.xml --module=/usr/share/yuma/modules/ietf/ietf-interfaces@2014-05-08.yang --module=/usr/share/yuma/modules/ietf/iana-if-type@2014-05-08.yang 1>tmp/netconfd.stdout 2>tmp/netconfd.stderr
 BAD_RES=$?
 cat tmp/netconfd.stdout
 if [ "$BAD_RES" == "0" ] ; then
